@@ -310,7 +310,7 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
   }
   else {
     regress <- try(opt.gmm.gb2(cprob, share, init.est = c(nls.a, temp.b, nls.p, nls.q), cons.est = c(nls.a, temp.b, nls.p, nls.q)))
-    if('try-error'%in%class(regress)) {
+    if('try-error'%in%class(regress$opt1)) {
       print("Unable to compute GMM estimates of the parameters. The weight martrix cannot be inverted. Try changing the value of rescale")
       gmm.coef <- matrix(NA, 1, 4)
       gmm.se <- matrix(NA, 1, 4)
@@ -368,6 +368,9 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
   colnames(gmm.estimation) <- c("a", "b", "p", "q")
   row.names(gmm.estimation) <- c("Coef.", "se")
 
+  grouped.data <- rbind(share, cprob)
+  row.names(grouped.data) <- c("Income", "Population")
+
   if (gini == TRUE) {
     if (!is.na(gmm.rss)) {
       gmm.gini <- simgini.gb2(gmm.coef)
@@ -379,11 +382,11 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
     gini.estimation[1] <- gini.e
     gini.estimation[2] <- nls.gini
     gini.estimation[3] <- gmm.gini
-    out2 <- list(nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss,
+    out2 <- list(grouped.data = grouped.data, distribution = "GB2", nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss,
       gini.estimation = gini.estimation)
   }
   else {
-    out2 <- list(nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss)
+    out2 <- list(grouped.data = grouped.data, distribution = "GB2", nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss)
   }
   return(out2)
 }
